==> vivanta_connect_flutter-0.7.0.tar.gz: README.md <==
# Vivanta Connect for Flutter

Plugin to integrate Vivanta Connect in Flutter Projects

## How to implement Vivanta Connect Flow

1. Add the import of Vivanta Connect

```dart
import 'package:vivanta_connect_flutter/views/start_vivanta_connect.dart';
```

2. Create a route to open Vivanta Connect. For example:

```dart
 Navigator.of(context).push(
  MaterialPageRoute(
    builder: (context) => VivantaConnectFlutter(
      apiKey: apiKey,                   // Required
      customerId: customerId,           // Required
      externalUserId: externalUserId,   // Required
      companyId: companyId,             // Optional
    ),
  ),
);
```

3. Vivanta Connect will start and automatically set the language based on the configuration of the device.

**Note:** Vivanta Connect requires a valid API Key and the associated Customer ID to fully function.

## How to implement Embedded Graphs

1. Create a route to open an Embedded Graph

```dart
Navigator.of(context).push(
  MaterialPageRoute(
    builder: (context) => EmbeddedGraph(
      apiKey: apiKey,                    // Required
      customerId: customerId,            // Required
      externalUserId: externalUserId,    // Required
      graphType: graphType,              // Required (Sleep, Active Time, Activity)
      brandId: brandId,                  // Optional, only for users with more than 1 brand connected
    ),
  ),
);
```

## Only for Apple Health integrations (iOS)

1. Add this code at the start of your user's session for obtaining and syncing Apple Health data.

```dart
  import 'package:vivanta_connect_flutter/helpers/vivanta_sync.dart';

  final vivantaSyncData = VivantaSync(
    apiKey: apiKey,                   // Required
    customerId: customerId,           // Required
    externalUserId: externalUserId,   // Required
  );
  vivantaSyncData.executeAll();       // This process gets data from HealthKit and uploads to Vivanta
);
```

2. Add the following elements in the Info.plist file.

```plist
<key>NSHealthShareUsageDescription</key>
<string>[Add here the purpose for reading from Apple Health]</string>
<key>NSHealthUpdateUsageDescription</key>
<string>[Add here the purpose for writing to Apple Health]</string>
```

## Only for Google Health Connect integrations (Android)

1. Add the following code in your AndroidManifest.xml, inside the root node:

```xml
  <queries>
    <package android:name="com.google.android.apps.healthdata" />
    <package android:name="com.google.android.apps.fitness" />
  </queries>
```

2. Add the following code in your main `<activity>` node:

```xml
  <intent-filter>
    <action android:name="androidx.health.ACTION_SHOW_PERMISSIONS_RATIONALE" />
  </intent-filter>
```

3. Add at least one of the permissions that your app will have access, in your AndroidManifest.xml inside the root node. The complete list of permissions is in [https://developer.android.com/health-and-fitness/guides/health-connect/plan/data-types#alpha10](this link). For example:

```xml
    <uses-permission android:name="android.permission.health.READ_STEPS"/>
```

4. In your `gradle.properties` file, replace this values:

```groovy
org.gradle.jvmargs=-Xmx1536M
android.enableJetifier=true
android.useAndroidX=true
```

5. Add this code at the start of your user's session for obtaining and syncing Google Health Connect data.

```dart
  import 'package:vivanta_connect_flutter/helpers/vivanta_sync.dart';

  final vivantaSyncData = VivantaSync(
    apiKey: apiKey,                   // Required
    customerId: customerId,           // Required
    externalUserId: externalUserId,   // Required
  );
  vivantaSyncData.executeAll();       // This process gets data from HealthKit and uploads to Vivanta
);
```

==> vivanta_connect_flutter-0.7.2.tar.gz: README.md <==
# Vivanta Connect for Flutter

Plugin to integrate Vivanta Connect in Flutter Projects

## How to implement Vivanta Connect Flow

1. Add the import of Vivanta Connect

```dart
import 'package:vivanta_connect_flutter/views/start_vivanta_connect.dart';
```

2. Create a route to open Vivanta Connect. For example:

```dart
 Navigator.of(context).push(
  MaterialPageRoute(
    builder: (context) => VivantaConnectFlutter(
      apiKey: apiKey,                   // Required
      customerId: customerId,           // Required
      externalUserId: externalUserId,   // Required
      companyId: companyId,             // Optional
    ),
  ),
);
```

3. Vivanta Connect will start and automatically set the language based on the configuration of the device.

**Note:** Vivanta Connect requires a valid API Key and the associated Customer ID to fully function.

## How to implement Embedded Graphs

1. Create a route to open an Embedded Graph

```dart
Navigator.of(context).push(
  MaterialPageRoute(
    builder: (context) => EmbeddedGraph(
      apiKey: apiKey,                    // Required
      customerId: customerId,            // Required
      externalUserId: externalUserId,    // Required
      graphType: graphType,              // Required (Sleep, Active Time, Activity)
      brandId: brandId,                  // Optional, only for users with more than 1 brand connected
    ),
  ),
);
```

## Only for Apple Health integrations (iOS)

1. Add this code at the start of your user's session for obtaining and syncing Apple Health data.

```dart
  import 'package:vivanta_connect_flutter/helpers/vivanta_sync.dart';

  final vivantaSyncData = VivantaSync(
    apiKey: apiKey,                   // Required
    customerId: customerId,           // Required
    externalUserId: externalUserId,   // Required
  );
  vivantaSyncData.executeAll();       // This process gets data from HealthKit and uploads to Vivanta
);
```

2. Add the following elements in the Info.plist file.

```plist
<key>NSHealthShareUsageDescription</key>
<string>[Add here the purpose for reading from Apple Health]</string>
<key>NSHealthUpdateUsageDescription</key>
<string>[Add here the purpose for writing to Apple Health]</string>
```

## Only for Google Health Connect integrations (Android)

1. Add the following code in your AndroidManifest.xml, inside the root node:

```xml
  <queries>
    <package android:name="com.google.android.apps.healthdata" />
    <package android:name="com.google.android.apps.fitness" />
  </queries>
```

2. Add the following code in your main `<activity>` node:

```xml
  <intent-filter>
    <action android:name="androidx.health.ACTION_SHOW_PERMISSIONS_RATIONALE" />
  </intent-filter>
```

3. Add at least one of the permissions that your app will have access, in your AndroidManifest.xml inside the root node. The complete list of permissions is in this link: <https://developer.android.com/health-and-fitness/guides/health-connect/plan/data-types#alpha10>. For example:

```xml
    <uses-permission android:name="android.permission.health.READ_STEPS"/>
```

4. In your `gradle.properties` file, replace this values:

```groovy
org.gradle.jvmargs=-Xmx1536M
android.enableJetifier=true
android.useAndroidX=true
```

5. Add this code at the start of your user's session for obtaining and syncing Google Health Connect data.

```dart
  import 'package:vivanta_connect_flutter/helpers/vivanta_sync.dart';

  final vivantaSyncData = VivantaSync(
    apiKey: apiKey,                   // Required
    customerId: customerId,           // Required
    externalUserId: externalUserId,   // Required
  );
  vivantaSyncData.executeAll();       // This process gets data from HealthKit and uploads to Vivanta
);
```
